===============
pywe-pay-notify
===============

Wechat Pay Notify Module for Python.

Installation
============

::

    pip install pywe-pay-notify


Usage
=====

::

    from pywe_pay_notify import check_pay_notify


Method
======

::

    def check_pay_notify(xml, check_sign=True, api_key=None, wx_configs=None, trade_cfg=None, trade_cfg_func=None, api_key_func=None)

